@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2002 Oliver Heidelbach
+@c Copyright (C) 1993/2003 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -45,6 +45,9 @@ Computer Associates (manufacturer)
 @item CAAD
 Computer Aided Architectural Design
 
+@item CABAC
+Context Based Adaptive Binary Arithmetic Coding (AVC)
+
 @item CABS
 Carrier Access Billing System
 
@@ -100,7 +103,7 @@ Computer Aided Instruction
 Computer Analysis of Images and Patterns (conference)
 
 @item CAIS
-Common APSE Interface Specification
+Common APSE Interface Specification (APSE, API)
 
 @item CAIT
 Center for the Application of Information Technology (org., USA)
@@ -142,11 +145,14 @@ Computer Assisted Material Management
 Complete Area Networks (SNI)
 
 @item CAN
-Controller Area Network
+Controller Area Network [bus] (CAN)
 
 @item CAO
 Computer Aided Office
 
+@item CAO
+Control Area Operator (EMS)
+
 @item CAP
 Carrierless Amplitude Phase [modulation] (ADSL, AT&T)
 
@@ -177,6 +183,9 @@ Computer Aided Process Planning
 @item CAPSL
 CAnnon Printing System Language (Canon), "CaPSL"
 
+@item CAPTCHA
+Completely Automated Public Turing test to tell Humans from Computers Apart (AI)
+
 @item CAQ
 Computer Aided Quality [control]
 
@@ -189,6 +198,9 @@ Computer Aided Retrieval
 @item CAR
 Computer Assisted Radiology
 
+@item CAR
+Contents of the Address Register (IBM, ELISP, CDR)
+
 @item CARCAS
 Computer Aided aRchiving and Change Accounting System
 
@@ -270,6 +282,9 @@ Constant Angular Velocity (CD, HDD, MOD)
 @item CAVE
 Cave for Automated Virtual Environment (VR)
 
+@item CAVLC
+Context-Adaptive Variable Length Coding (AVC)
+
 @item CAVO
 Computer Associates - Visual Objects (CA, DB), "CA-VO"
 
@@ -291,9 +306,15 @@ Character Bitmap Distribution Format (Adobe)
 @item CBDS
 Connectionless Broadband Data Service (Europe)
 
+@item CBDTPA
+Consumer Broadband and Digital Television Promotion Act (USA, DRM)
+
 @item CBE
 Certified Banyan Engineer (Banyan, VINES)
 
+@item CBEFF
+Common Biometric Exchange Format Framework (NIST)
+
 @item CBEMA
 Computer & Business Equipment Manufacturers Association (org.)
 
@@ -313,7 +334,7 @@ Connectionless Broadband Data Service
 Class Based Queueing
 
 @item CBR
-Constant Bit Rate (ATM, VBR, ABR, UBR, QOS)
+Constant Bit Rate (ATM, VBR, ABR, UBR, QOS, BIT)
 
 @item CBS
 Certified Banyan Specialist (Banyan, VINES)
@@ -379,7 +400,7 @@ Connection Control Entity
 Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France)
 
 @item CCF
-??? (org.)
+Campus Computing Facilities (org.)
 
 @item CCF
 Capsulated Color Filter (NEC)
@@ -417,6 +438,9 @@ Change Configuration Management
 @item CCM
 CORBA Component Model (CORBA)
 
+@item CCM
+Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610)
+
 @item CCNC
 Common Channel Network Controller
 
@@ -465,11 +489,14 @@ Common Communications Support (IBM, SAA)
 @item CCS
 Communications-Computer Systems, "C-CS"
 
+@item CCS
+Computerized Charging System
+
 @item CCS
 Cyprus Computer Society (Org, Zypern)
 
 @item CCS7
-Common Channel signaling System 7 (IN, Telekom, CCITT)
+Common Channel signaling System 7 (IN, DTAG, CCITT)
 
 @item CCSID
 Coded Character Set IDentification (IBM)
@@ -493,7 +520,7 @@ Cache Control Unit (Wyse)
 Customer Control Unit
 
 @item CCV
-C-bit Coding Violation [error event] (DS3/E3)
+C-bit Coding Violation [error event] (DS3/E3, BIT)
 
 @item CCW
 COM Callable Wrapper (MS, COM, Java)
@@ -517,7 +544,7 @@ Communications Decency Act (Internet, USA)
 Compound Document Architecture (DEC)
 
 @item CDATA
-Character DATA (XML, PCDATA)
+Character DATA (DTD, PCDATA)
 
 @item CDB
 Command Descriptor Block
@@ -594,6 +621,9 @@ Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI"
 @item CDMO
 Compact Disk - Magneto Optical (CD), "CD-MO" 
 
+@item CDMRW
+Compact Disk - Mount Rainier Washington (CD-RW, CD), "CD-MRW"
+
 @item CDMS
 Communication Driver Maintenance System (ISDN, HST)
 
@@ -615,6 +645,9 @@ Cellular Digital Packet Data (mobile-systems)
 @item CDR
 Compact Disk - Recordable (CD), "CD-R" 
 
+@item CDR
+Contents of the Decrement Register (IBM, ELISP, CAR)
+
 @item CDRA
 Character Data Representation Architecture
 
@@ -642,6 +675,9 @@ Current Directory Structure (BIOS. DOS)
 @item CDSA
 Common Data Securuty Architecture (HP, cryptography)
 
+@item CDSG
+Cultural Diversity Steering Group (ISSS)
+
 @item CDSS
 Creative Decision Stimulation Systems (AI, DSS)
 
@@ -684,12 +720,21 @@ welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 @item CECI
 CICS Enhanced Command Interpreter (IBM, CICS)
 
+@item CECMG
+Central Europe Computer Measurement Group (org., Europe), "cecmg"
+
 @item CEDA
 ??? (CICS, IBM)
 
+@item CEDF
+CICS Execution Diagnostic Facility (CICS, IBM)
+
 @item CEDR
 [Microsoft Windows] Compact Edition Driver Repository (MS, Windows, CE)
 
+@item CEE
+[Linux] Consumer Electronics Edition (MontaVista, Linux, PDA)
+
 @item CEECEB
 Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"
 
@@ -702,6 +747,9 @@ Continuous Edge Graphics (Grafik, IC)
 @item CEI
 Connection Endpoint Identifier (UNI)
 
+@item CELL
+CIP/Ethernet Library for Linux (Linux, ethernet, CIP, PLC)
+
 @item CELP
 Card Edge Low Profile [socket]
 
@@ -715,7 +763,7 @@ Contract Equipment Manufacturer
 ??? (CICS, IBM)
 
 @item CEN
-Comite Europeen de Normalisation (Europe, Brussels)
+Comite Europeen de Normalisation (org., Europe, Brussels)
 
 @item CENELEC
 Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
@@ -745,7 +793,7 @@ Conseil Europeenne pour la Recherche Nucleaire (org., Europe, Geneva)
 Computer Emergency Response Team (DARPA, CMU, Internet)
 
 @item CES
-C-bit Errored Seconds (DS3/E3)
+C-bit Errored Seconds (DS3/E3, BIT)
 
 @item CES
 Character Encoding Scheme (CSS, Unicode)
@@ -786,6 +834,9 @@ Code Fiels Address (Forth)
 @item CFB
 Cipher FeedBack [mode] (cryptography, DES)
 
+@item CFC
+ColdFusion Component (WWW, HTTPD)
+
 @item CFD
 Call For Discussion (Internet)
 
@@ -840,6 +891,9 @@ Graphics Communications Association (org.)
 @item CGARI
 Graphics Communications Association Research Institute (org., CGA)
 
+@item CGATS
+Committee for Graphics Arts Technologies Standards (org., ANSI)
+
 @item CGDC
 Computer (???) Game Developers' Conference
 
@@ -912,6 +966,9 @@ Configuration Item (CM)
 @item CI
 Congestion Indicator
 
+@item CIA
+CAN In Automation (org., CAN), "CiA"
+
 @item CIAC
 Computer Incident Advisory Capability (org., LLNL, Internet)
 
@@ -928,7 +985,7 @@ Coordination and Information Center (CSNET)
 Center of Innovative Computer Applications (org.)
 
 @item CICS
-Customer Information Control System (IBM, CICS)
+Customer Information Control System (IBM, CICS, Z/OS, OS/390, VSE/ESA)
 
 @item CICSESA
 Customer Information Control System/Enterprise Systems Architecture (IBM, CICS), "CICS/ESA"
@@ -951,9 +1008,15 @@ Classless Internet DOMAIN Routing [protocol] (RFC 1519)
 @item CIE
 Commission Internationale de l'Eclairage (org.)
 
+@item CIF
+Common Intermediate Format [352x288] (video)
+
 @item CIFS
 Common Internet File System (TCP/IP)
 
+@item CIL
+Common Intermediation Language (CLI)
+
 @item CIL
 Computer Integration Laboratories (org., Apple, IBM, Novell, Sun, ...)
 
@@ -964,13 +1027,13 @@ Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CIL
 Cisco Interactive Mentor (Cisco)
 
 @item CIM
-Common Information Model (DMTF, XML, DMI)
+Common Information Model (DMTF, XML, DMI, SAN)
 
 @item CIM
 Computer Integrated Manufacturing
 
 @item CIMOM
-CIM Object Model (CIM)
+CIM Object Model (CIM, WBEM)
 
 @item CIMOS
 CIncinnati Milacron Operating System (OS), "CiMOS"
@@ -984,6 +1047,12 @@ Carrier Identification Parameter
 @item CIP
 Classical IP over ATM (IP, ATM, IETF)
 
+@item CIP
+Common Industrial Protocol (ODVA)
+
+@item CIP
+Common ISDN Profile (Bluetooth, CAPI, ISDN)
+
 @item CIP
 Computer Integrated Processing
 
@@ -1044,12 +1113,18 @@ Copyright In Transmitted Electronic Documents (ESPRIT)
 @item CIU
 ??? [switch] (IBM)
 
+@item CIU
+Core Interface Unit (Power4, IBM, IC)
+
 @item CIVIC
 Cyclone Integrated Video Interfaces Controller (Apple)
 
 @item CIX
 Commercial Internet eXchange (ISP)
 
+@item CJK
+Chinese - Japanese - Korean [encoding]
+
 @item CL
 Column Address Strobe Latency (CAS, IC)
 
@@ -1071,6 +1146,9 @@ Custom Local Area Signaling Service
 @item CLDC
 Connected Limited Device Configuration (KVM, CDC)
 
+@item CLE
+Certified Linux Engineer (Novell, Linux)
+
 @item CLE
 Certified Lotus Engineer (Lotus)
 
@@ -1080,6 +1158,9 @@ Competitive Local Exchange Carrier
 @item CLI
 Call Level Interface (DB, SAG, X/Open, Oracle, Informix, MS, ...)
 
+@item CLI
+Class LIbrary (CLI)
+
 @item CLI
 CLear Interrupt (assembler)
 
@@ -1087,7 +1168,7 @@ CLear Interrupt (assembler)
 Command Line Interpreter / Interface (OS)
 
 @item CLI
-Common Language Infrastructure (MS, .NET, ECMA)
+Common Language Infrastructure (MS, .NET, ECMA, CLI)
 
 @item CLIC
 Chemnitzer LInux Cluster (Linux, Chemnitz), "CLiC"
@@ -1132,7 +1213,7 @@ Common Language Runtime (MS, CLI, .NET)
 Card Loading Signal
 
 @item CLS
-Common Language Specification (OOP, CLR, MS, .NET)
+Common Language Specification (OOP, CLR, MS, .NET, CLS)
 
 @item CLSF
 ConnectionLess Service Function
@@ -1192,7 +1273,7 @@ Cambridge Model Distributed System (OS)
 Component Management Entity
 
 @item CMGA
-Community of Massive Gaming Agents Internet, Germany, Telekom
+Community of Massive Gaming Agents Internet, Germany, DTAG
 
 @item CMGS
 Cyan Magenta Gelb Schwarz (color system, DTP)
@@ -1218,6 +1299,9 @@ Common Management Information Service Element (CMIS)
 @item CMM
 Color Management Method (DTP, ICM)
 
+@item CMMI
+Capability Maturity Model Integration
+
 @item CMMU
 Cache/Memory Management Unit
 
@@ -1233,6 +1317,9 @@ Complementary-symmetry Metal-Oxide Semiconductor (IC)
 @item CMOT
 CMIP Over TCP (OSI, RFC 1189, CMIP, TCP)
 
+@item CMP
+Chip MultiProcessing (IBM, HP, Sun)
+
 @item CMP
 Container-Managed Persistence [beans] (Java, EJB)
 
@@ -1266,6 +1353,9 @@ Connection ManagemenT (FDDI)
 @item CMU
 Carnegie-Mellon-University (org.)
 
+@item CMX
+Communications Manager uniX (Unix)
+
 @item CMY
 Cyan Magenta Yellow (color system, DTP)
 
@@ -1323,6 +1413,9 @@ Centre Nationale d'Etudes des Telecommunications (org., France)
 @item CNI
 Certified Netware Instructor (Novell, Netware)
 
+@item CNI
+Coalition for Networked Information (org.)
+
 @item CNI
 Common Network Interface
 
@@ -1362,6 +1455,9 @@ Complimentary Network Service
 @item CNS
 Compuserve Network Services (CIS)
 
+@item CNTFET
+Carbon Nano-Tube Field Effect Transistor
+
 @item CO
 Check Out (RCS)
 
@@ -1381,7 +1477,7 @@ Computer Operations, Audit and Security Technology (org.)
 COmmon Business Orientated Language
 
 @item COBRA
-??? (org., Netherlands)
+COmmunication technology: Basic Research and Applications (org., Netherlands)
 
 @item COBRA
 COmmunication technology: Basic Research and Applications
@@ -1416,11 +1512,14 @@ COder - DECoder
 @item COE
 Central Office Equipment
 
+@item COE
+Common Operating Environment [certification] (DISA, mil.)
+
 @item COEES
 COE Engineering System (COE)
 
 @item COFDM
-??? (Digital audio)
+Coded Orthogonal Frequency Division Multiplexing (Digital audio, DAB)
 
 @item COFF
 Common Object File Format (Unix)
@@ -1468,7 +1567,7 @@ Communications for North Carolina Education, Research and Technology (network)
 COSINE Network's Central Information Service for Europe (COSINE, network)
 
 @item CONLAN
-??? [hardware description language] (HDL)
+CONsensus LANguage (HDL)
 
 @item CONS
 Connection Oriented Networking Service
@@ -1584,6 +1683,9 @@ Comprehensive PERL Archive Network (PERL)
 @item CPC
 Cost Per Copy
 
+@item CPCI
+Compact Peripheral Component Interconnect (PCI), "cPCI"
+
 @item CPCS
 Common Part Convergence Sublayer (ATM)
 
@@ -1632,6 +1734,9 @@ Conversational Programming Language (DEC)
 @item CPLD
 Complex Programmable Logic Device (PLD, IC, RL)
 
+@item CPM
+Communication Processor Module (Motorola)
+
 @item CPM
 Control Program for Microcomputers (OS, DR), "CP/M"
 
@@ -1740,6 +1845,9 @@ Complex-Reduced Instruction Set Computer
 @item CRISP
 Complex-Reduced Instruction Set Processor
 
+@item CRISP
+Cross Registry Internet Service Protocol (Internet)
+
 @item CRJE
 Conversational Remote Job Entry (RJE)
 
@@ -1779,6 +1887,9 @@ Computer Technology Research [corporation] (provider)
 @item CRTC
 Cathode Ray Tube Controller (EGA, VGA, MCGA)
 
+@item CRTM
+Core Root of Trust for Management (TCPA)
+
 @item CS
 Carrier Selection
 
@@ -1815,6 +1926,9 @@ Callpath Service Architecture (IBM, CTI)
 @item CSA
 Client Service Agent
 
+@item CSA
+Communication Streaming Architecture (Intel, MCH, DNB)
+
 @item CSA
 Configuration Status Accounting
 
@@ -1867,7 +1981,7 @@ Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)
 Centre Suisse d'Electronique et de Microtecnique (org., Switzerland)
 
 @item CSES
-C-bit Severely Errored Seconds (DS3/E3)
+C-bit Severely Errored Seconds (DS3/E3, BIT)
 
 @item CSG
 Constructive Solid Geometry (CAD, CAM)
@@ -2043,6 +2157,9 @@ Cell Transfer Delay (UNI, ATM, QOS)
 @item CTE
 Compliance Test and Evaluation, "CT & E"
 
+@item CTEA
+Copyright Term Extension Act (USA,  DRM)
+
 @item CTERM
 Command TERMinal (DEC)
 
@@ -2058,6 +2175,9 @@ Communication Trunk of Medium range Mil., Germany
 @item CTOS
 Cassette Tape Operating System (OS, Datapoint)
 
+@item CTP
+Cordless Telephony Profile (Bluetooth)
+
 @item CTR
 [columbia university] Center for Telecommunications Research (org., USA)
 
@@ -2074,7 +2194,10 @@ Cipher Text Stealing [mode] (cryptography)
 Clear To Send (MODEM, RS-232)
 
 @item CTS
-Common Type System (OOP, CLR, MS, .NET)
+Common Type System (OOP, CLR, MS, .NET, CLS)
+
+@item CTS
+Compatibility Test Suite (Sun, J2EE)
 
 @item CTS
 Conformance Testing Service (OSTC)
@@ -2107,7 +2230,7 @@ Console teleTYpe
 Call Up (Unix)
 
 @item CU
-[L]       [see you [Later]] (telecommunication-slang, Usenet, IRC)
+[L]       [see you [Later]] (slang, Usenet, IRC)
 
 @item CUA
 Common User Application
@@ -2178,6 +2301,9 @@ Current Workspace Pointer (SPARC, CPU)
 @item CWT
 Character Width Table
 
+@item CXFS
+Clustered eXtended File System (SGI, RAID, XFS)
+
 @item CXI
 Common X-windows Interface (Unix)
 
