@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2002 Oliver Heidelbach
+@c Copyright (C) 1993/2003 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -16,7 +16,7 @@ FORTRAN to C [converter]
 Frequency - Double Frequency
 
 @item FA
-FernmeldeAmt (Telekom)
+FernmeldeAmt (DTAG)
 
 @item FAA
 Flow Admission Acknowledge [message] (LFAP)
@@ -51,6 +51,9 @@ Field Application Engineer
 @item FAG
 FernmeldeAnlagenGesetz telecommunication, Germany
 
+@item FAID
+Flash Authority Identification Data (EEPROM)
+
 @item FAIS
 Finnish Artificial Intelligence Society (org., Finland, AI)
 
@@ -73,7 +76,7 @@ Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 Family Application Programmer Interface (DOS, VDM, API)
 
 @item FAQ
-Frequently Asked Questions (telecommunication-slang, Usenet)
+Frequently Asked Questions (slang, Usenet)
 
 @item FAR
 False Acception Rate
@@ -84,6 +87,9 @@ Fixed Alternative Routing (SNI)
 @item FAR
 Flow Admission Request [message] (LFAP)
 
+@item FARE
+Film Automatic Retouching and Enhancement (Canon, Scanner)
+
 @item FARNET
 Federation of American Research NETworks (network)
 
@@ -93,6 +99,9 @@ Flow Admission Service
 @item FASMI
 Fast Analysis of Shared Multidimensional Information (OLAP)
 
+@item FAST
+Fast ARM Solutions Toolkit (ARM, Palm, PDA)
+
 @item FAST
 First Application System Test
 
@@ -111,6 +120,9 @@ Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany)
 @item FAW
 Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm)
 
+@item FAXP
+FAX Profile (Bluetooth, SPP), "FaxP"
+
 @item FB
 Fiber optic Backbone
 
@@ -123,6 +135,9 @@ Frame Burst error Length (CD)
 @item FBM
 Flexible Buffer Management (QMS)
 
+@item FBPP
+Federal Biomteric Protection Profile (NIAP)
+
 @item FBS
 Flexible Bandwidth Service (ATM, SDH)
 
@@ -153,6 +168,9 @@ File Control Block (DOS)
 @item FCBS
 File Control BlockS (DOS)
 
+@item FCC
+Fast Communication Controler (SCC, MCC)
+
 @item FCC
 Federal Communications Commission (org., USA)
 
@@ -171,6 +189,9 @@ Floating Car Data
 @item FCFS
 First Come, First Served
 
+@item FCGS4
+Fibre Channel Generic Service 4 (FC, SAN, ANSI), "FC-GS-4"
+
 @item FCH
 Frame Control Channel (HiperLAN/2)
 
@@ -183,8 +204,17 @@ Flow Control Indicator (DLSW)
 @item FCI
 Forward Cache Identifier (CATNIP)
 
+@item FCIP
+Fibre Channel over Internet Protocol (SAN, FC, IP)
+
+@item FCL
+Framework Class Library (MS, .NET)
+
+@item FCMI
+Fibre Channel Methodology for Interconnects (FC, SAN, ANSI), "FC-MI"
+
 @item FCO
-Flow Control Operator Bits (DLSW)
+Flow Control Operator Bits (DLSW, BIT)
 
 @item FCP
 [SCSI-3] Fibre Channel Protocol (SAM)
@@ -210,6 +240,9 @@ Frame Check Sequence (FDDI, Token Ring)
 @item FCS
 Frame Check Sum (MODEM)
 
+@item FCSAN
+Fibre Channel Storage Area Network (FC, SAN)
+
 @item FDA
 FORTRAN Design Aid (FORTRAN)
 
@@ -267,6 +300,9 @@ Frequency Division/Time Division Multiple Access (mobile-systems, GSM), "FD/TDMA
 @item FDX
 Full DupleX
 
+@item FE
+Focus Error (DVD)
+
 @item FE
 Forschung und Entwicklung, "F&E"
 
@@ -339,6 +375,9 @@ First Failure Data Capture
 @item FFDT
 FDDI Full Duplexing Technology (FDDI)
 
+@item FFII
+Foerderverein fuer Freie Informationelle Infrastruktur (org.)
+
 @item FFOL
 FDDI Follow-On-LAN
 
@@ -346,7 +385,7 @@ FDDI Follow-On-LAN
 Fallback Fault-tolerant Server (IBM, OS/2)
 
 @item FFS
-Fast File System (Amiga, Commodore)
+Fast File System (Unix, Amiga, Commodore)
 
 @item FFS
 Fast Filing System (BSD, Unix)
@@ -456,6 +495,9 @@ Federal Information Resources Management Regulations (USA)
 @item FIRP
 Federal Internet Requirements Panel (Internet, USA)
 
+@item FIRS
+Federated Internet Registry Service (LDAP, Internet)
+
 @item FIRST
 ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany)
 
@@ -468,12 +510,18 @@ FachInformationsSystem
 @item FIS
 FuehrungsInformationsSysteme
 
+@item FISH
+FIle transfer with a SHell, "FiSH"
+
 @item FIT
 Failures In Time
 
 @item FITS
 Functional Interpolating Transformation System
 
+@item FITUG
+Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.)
+
 @item FIU
 Fingerprint Identification Unit (Sony)
 
@@ -522,9 +570,15 @@ Frequenz-Modulation
 @item FMA
 Federated Management Architecture (Java)
 
+@item FMB
+Flexible MotherBoard [design]
+
 @item FMM
 Flash Memory Manager (Intel)
 
+@item FMO
+Flexible Macroblock Ordering (AVC, video)
+
 @item FMS
 FernMeldeSystem
 
@@ -537,6 +591,9 @@ Far More Than Everything You Ever Wanted To Know (slang, PERL)
 @item FNC
 Federal Networking Council (org., USA)
 
+@item FNI
+FachNormenausschuss Informationsverarbeitung [1962-1987] (DIN, NI, predecessor)
+
 @item FO
 Fiber Optic
 
@@ -559,7 +616,7 @@ Formal specification of ODA document structures (ODA, ISO)
 [international conference on] Foundations Of Data Organization and algorithms (conference, INRIA)
 
 @item FOEBUD
-[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBud"
+[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD"
 
 @item FOIRL
 Fiber Optic InterRepeater Link (OWG)
@@ -574,7 +631,7 @@ Free OnLine Dictionary Of Computing (WWW, UK)
 Flexible Organic Light Emitting Display (OLED)
 
 @item FOMAU
-Fiber Optic MAU (ethernet)
+Fiber Optic MAU (ethernet, MAU)
 
 @item FON
 Fiber Optics Network
@@ -586,7 +643,7 @@ FTP Operation Over Big Address Records (RFC 1639, FTP)
 Forum for Object Oriented Technology (CERN, OOP)
 
 @item FOP
-Formatting Object Processor (Apache)
+Formatting Object Processor (Apache, XSL-FO)
 
 @item FORMEX
 FORMalised EXchange of electronic publications (SGML, Europe)
@@ -616,7 +673,7 @@ Fiber Optic Transceiver
 Follow-on Operational Test and Evaluation, "FOT & E"
 
 @item FOURCC
-FOUR Character Code (RIFF, TIFF)
+FOUR Character Code (RIFF, TIFF, VFW, DivX)
 
 @item FOV
 Field Of View (VRML)
@@ -633,6 +690,9 @@ Floating Point Accelerator
 @item FPAA
 Field Programmable ALU Array (IC, ALU, RL)
 
+@item FPBGA
+Fine Pitch Ball Grid Array (CPU, IC)
+
 @item FPC
 Floating Point Coprocessor
 
@@ -720,6 +780,9 @@ Frame Relay Access Device
 @item FRAM
 Ferroelectric Random Access Memory (RAM, IC)
 
+@item FRC
+Frame Rate Control (PDP)
+
 @item FRD
 Functional Requirements Description
 
@@ -793,7 +856,7 @@ Finite State Machine (TTCN, ...)
 Freiwillige Selbstkontrolle Multimedia Org., Germany
 
 @item FSMGDOS
-??? Graphics Device Operating System (OS, Atari)
+Font Scaling Manager - Graphics Device Operating System (OS, Atari), "FSM-GDOS"
 
 @item FSO
 [scripting runtime library] File System Objects (MS, WSH)
@@ -886,7 +949,7 @@ Federal Telecommunications Standards Committee (org., USA)
 Fidonet Technical Standard Conference (conference)
 
 @item FTZ
-FernmeldeTechnische Zentralamt / Zulassung (Telekom, ZZF, predecessor)
+FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)
 
 @item FUA
 Flow Update Acknowledge [message] (LFAP)
@@ -898,10 +961,10 @@ Freie Universitaet Berlin (org.)
 Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
 
 @item FUBAR
-Fouled / Fucked Up Beyond All Recognition / Repair (telecommunication-slang, Usenet, IRC)
+Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)
 
 @item FUD
-Fear, Uncertainty, & Doubt (slang, IBM)
+Fear, Uncertainty & Doubt (slang, IBM)
 
 @item FUN
 Flow Update Notification [message] (LFAP)
@@ -910,13 +973,13 @@ Flow Update Notification [message] (LFAP)
 Frame User Network Interface
 
 @item FUEV
-Fernmeldeanlagen-UeberwachungsVerordnung
+Fernmeldeanlagen-UEberwachungsVerordnung
 
 @item FWH
 FirmWare Hub (BIOS, Intel)
 
 @item FWIW
-For What It's Worth (telecommunication-slang, Usenet, IRC)
+For What It's Worth (slang, Usenet, IRC)
 
 @item FWT
 Fast Wavelet Transformation
@@ -925,7 +988,7 @@ Fast Wavelet Transformation
 FiXed point Unit (POWER, CPU)
 
 @item FYI
-For Your Information (telecommunication-slang, Usenet, IRC)
+For Your Information (slang, Usenet, IRC)
 
 @item FZA
 ??? [compression]
