@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2002 Oliver Heidelbach
+@c Copyright (C) 1993/2003 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -63,6 +63,9 @@ Multiple APIC Description Table (ACPI, APIC)
 @item MAE
 Macintosh Application Environment (Apple, Sun, HPUX)
 
+@item MAE
+Metropolitan Area Exchange (Internet)
+
 @item MAINSAIL
 MAchine INdependent SAIL (SAIL)
 
@@ -81,6 +84,9 @@ Multiple Arcade Machine Emulator, "M.A.M.E."
 @item MAN
 Metropolitan Area Network
 
+@item MANET
+Mobile Ad-hoc NETwork (Internet)
+
 @item MAP
 Maintenance Analysis Procedure (IBM)
 
@@ -99,6 +105,9 @@ Mobile Application Part - Application Service Elements (MAP, MSC, GSM, mobile-sy
 @item MAPI
 Messaging Application Program Interface (MS, WOSA, API)
 
+@item MAPOS
+Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)
+
 @item MAPTOP
 Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 
 
@@ -147,6 +156,9 @@ MAssively parallel uniX (Cray, OS, MIMD, MPP, Unix)
 @item MAX
 Media Access Exchange (Ascend)
 
+@item MAX
+Multimodaler AssemblierungseXperte (VR, Uni Bielefield)
+
 @item MB
 MailBox
 
@@ -156,14 +168,20 @@ MegaByte
 @item MBAG
 Mercedes-Benz AktienGesellschaft (user)
 
+@item MBC
+Multi Bit Cell (IC, PCMCIA, Flash, AMD, BIT)
+
 @item MBCMS
 Mercedes-Benz-Computer-Mikrofilm-System (MBAG), "MB-CMS"
 
 @item MBE
 Molecular Beam Epitaxy (IC; MOSFET)
 
+@item MBIT
+Mega Binary digIT (BIT), "MBit"
+
 @item MBPS
-MegaBits Per Second
+MegaBits Per Second (BIT)
 
 @item MBR
 Master Boot Record
@@ -180,8 +198,11 @@ Micro Channel Architecture (IBM, PS/2)
 @item MCA
 Mission Critical Applications
 
+@item MCA
+Model Centric Architecture (Skynamics)
+
 @item MCAD
-Mechanical CAD (AutoCAD, CAD)
+Mechanical CAD (carCAD, CAD)
 
 @item MCAV
 Modified Constant Angular Velocity
@@ -201,12 +222,18 @@ Manchester Computing Centre (Linux)
 @item MCC
 Mitteldeutsches Communication Center (Leipzig)
 
+@item MCC
+Multichannel Communication Controller (SCC, FCC)
+
 @item MCD
 Mini Client Driver (MS, Windows NT)
 
 @item MCD
 Multimedia Cartridge Drive (Nomai)
 
+@item MCE
+Media Center Edition (MS, Windows, XP, OEM)
+
 @item MCEB
 Military Communications-Electronics Board (org., mil., USA)
 
@@ -244,11 +271,14 @@ Metropolitan Campus Network
 Master Certified Netware Engineer (Novell, Netware)
 
 @item MCNS
-??? [cable modem standard] (org.)
+Multimedia Cable Network System (org.)
 
 @item MCP
 Master Control Program (OS)
 
+@item MCP
+Media and Communications Processor (IC)
+
 @item MCP
 Merlin Convenience Pack (IDB, OS/2)
 
@@ -309,6 +339,9 @@ Multiple Console Time Sharing System (OS, CAD)
 @item MCU
 Management & Cascade Unit (Hub)
 
+@item MCU
+Master Control Unit (Nokia, OS)
+
 @item MCU
 Micro Controller Unit (SIA, RL)
 
@@ -343,7 +376,7 @@ Mail Delivery Agent
 Medicated Digest Authentication (HTTP)
 
 @item MDA
-Model Driven Architecture (CASE)
+Model Driven Architecture (CASE, OMG)
 
 @item MDA
 Monochrome Display Adapter (IBM, PC)
@@ -370,7 +403,7 @@ Modified Discrete Cosine Transformation
 MultiDimensional DataBase (DB)
 
 @item MDE
-??? DatenErfassung
+Mobile DatenErfassung, "mDE"
 
 @item MDEF
 Menu DEfinintion Functions (Apple, CDEF)
@@ -390,6 +423,9 @@ Multiplex Device Interface
 @item MDIS
 MetaData Interchange Specification
 
+@item MDIX
+Medium Dependent Interface - crossed (MDI), "MDI-X"
+
 @item MDK
 MODEM Developers Kit (MODEM, MS)
 
@@ -435,8 +471,11 @@ Mapping Entity
 @item ME
 Millennium Edition (MS, Windows)
 
+@item MEC
+Memory Expansion Card
+
 @item MEG
-Mega Evil Grin (telecommunication-slang, Usenet, IRC)
+Mega Evil Grin (slang, Usenet, IRC)
 
 @item MEGA
 MessdatenErfassung und Graphische Auswertung
@@ -508,7 +547,7 @@ Multi Frequency
 Mwave Folded Array Signal Transform [DSP] (IBM, DSP)
 
 @item MFC
-Microsoft Foundation Classes
+Microsoft Foundation Classes (MS)
 
 @item MFC
 Music Feature Card (IBM, Yamaha, MIDI)
@@ -541,7 +580,7 @@ Million FLoating-point Operations Per Second (CPU)
 Modified Frequency Modulation
 
 @item MFP
-MultiFunction Product
+MultiFunction Product (HP)
 
 @item MFS
 Macintosh File System (Apple)
@@ -645,6 +684,9 @@ Message IDentifier (ATM)
 @item MID
 Mobile Information Device
 
+@item MID
+Multiple Interface Declaration (OLSR)
+
 @item MIDI
 Musical Instruments Digital Interface (MIDI)
 
@@ -652,7 +694,7 @@ Musical Instruments Digital Interface (MIDI)
 Microsoft Interface Definition Language (NT)
 
 @item MIDP
-Mobile Information Device Profile (J2ME)
+Mobile Information Device Profile (J2ME, Java)
 
 @item MIDPEG
 Mobile Information Device Profile Expert Group (Sun, AOL, Motorola, NEC, Nokia, Palm, Samsung, Sharp, ...)
@@ -687,6 +729,9 @@ Multiple Instruction [stream], Multiple Data [stream] (CPU)
 @item MIME
 Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
 
+@item MIMO
+Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
+
 @item MIMOLA
 Machine Independent MicrOprogramming LAnguage (HDL)
 
@@ -714,6 +759,9 @@ Memory Input/Output (Motorola)
 @item MIO
 Modular Input/Output [architecture] (HP)
 
+@item MIP
+Main Information Packet (CD-MRW)
+
 @item MIP
 Multimission Interactive Picture
 
@@ -756,6 +804,9 @@ Management Information Tree
 @item MIT
 Massachusetts Institute of Technology (org., USA)
 
+@item MIT
+Mobile Internet Toolkit (MS, .NET)
+
 @item MJ
 Modular Jack
 
@@ -768,9 +819,15 @@ Multifunktionelles KartenTerminal (CT, ICC)
 @item ML
 Mail List
 
+@item ML
+Maintenance Lead (JCP)
+
 @item ML
 Meta Language
 
+@item ML2
+MaskLess Lithography
+
 @item MLA
 Mail List Agent
 
@@ -780,6 +837,9 @@ Micro Lens Array
 @item MLC
 MultiLevel Cell (IC, PCMCIA, Flash, Intel)
 
+@item MLD
+Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710)
+
 @item MLE
 MultiLine Entry field (IBM, OS/2)
 
@@ -804,6 +864,9 @@ Multi-Level Multi-Access (MAC)
 @item MLP
 Meridian Lossless Packaging (DVD, audio)
 
+@item MLP
+Mozilla Localization Project (Mozilla)
+
 @item MLP
 MultiLink Point-to-Point Protocol (PPP)
 
@@ -834,6 +897,9 @@ Microcomputer Managers Association (org., USA)
 @item MMA
 MIDI Manufacturer Association (org., IMA)
 
+@item MMAPI
+Mobile Media API (Java, Sun, JMF, API)
+
 @item MMC
 Microsoft Management Console (MS, Windows NT)
 
@@ -888,6 +954,9 @@ Memory Mapped I/O (I/O)
 @item MML
 Maker Markup Language (FrameMaker)
 
+@item MMOG
+Massive Multiplayer Online Games
+
 @item MMP
 Multilink Multichasis PPP (PPP)
 
@@ -903,6 +972,9 @@ Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506
 @item MMS
 Maximum Message Size
 
+@item MMS
+Microsoft Media Server [protocol] (MS, Internet)
+
 @item MMS
 Module Making System (VMS)
 
@@ -961,7 +1033,7 @@ Measure of Effectiveness
 Molekulare Optisch-Elektrische Schaltungstraeger
 
 @item MOESI
-Modified - Owner - Exclusive - Shared - Invalid (AMD)
+Modified - Owned - Exclusive - Shared - Invalid (AMD)
 
 @item MOF
 Managed Object Format (CIM, DMTF)
@@ -1005,6 +1077,9 @@ Multiple Original Prints
 @item MOPS
 Million Operations Per Second
 
+@item MOR
+Mining Object Repository (OP, Oracle, DB)
+
 @item MOS
 Master Operating System (OS, Varian)
 
@@ -1068,6 +1143,9 @@ Magneto-Optical Write Once Read Many, "MO-WORM"
 @item MP
 [PPP] Multilink Protocol (MPPP, RFC 1990)
 
+@item MP
+MegaPIXEL (PIXEL, photo)
+
 @item MP
 Multi Processor
 
@@ -1101,8 +1179,14 @@ Motion Picture Expert Group [old term] (MPEG)
 @item MPEG
 Moving Picture Expert Group (org., ISO 11172-1, JTC1)
 
+@item MPEGTS
+Moving Picture Expert Group - Transport Stream (MPEG, TS), MPEG-TS
+
+@item MPEV
+Multiple Programming Executive/V (HP), "MPE/V"
+
 @item MPEXL
-??? (HP), "MPE/XL"
+Multiple Programming Executive/XL (HP), "MPE/XL"
 
 @item MPI
 Message Passing Interface (SMP, Cluster)
@@ -1122,6 +1206,9 @@ Multi-Protocol Label Switching (RFC 3031)
 @item MPM
 Metra Potential Method
 
+@item MPM
+Multi Processing Modul (Apache)
+
 @item MPM
 Multi-user ??? Program for Microcomputers (CP/M, OS, DR), "MP/M"
 
@@ -1165,7 +1252,10 @@ Microsoft Point to Point Encryption (MS, cryptography, RFC 3078)
 Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
 
 @item MPR
-[National Board for Metrology and Testing] (org., Sweden)
+Maet- och Provningsradet [National Board for Measurement and Testing] (org., Sweden, SWEDAC)
+
+@item MPR
+MultiPoint Relay (OLSR)
 
 @item MPS
 Megabytes Per Second
@@ -1177,7 +1267,7 @@ MPOA Server (MPOA, ATM)
 MultiPage Signal (Fax)
 
 @item MPS
-MultiProzessor Spezifikation (SMP)
+MultiProcessor Specification (SMP, Intel)
 
 @item MPSX
 Mathematical Programming System eXtended (IBM)
@@ -1189,7 +1279,7 @@ Ministery of Post and Telecommunications (org., Japan)
 MultiPort Transceiver
 
 @item MPT1327
-???
+[British] Ministry of Post and Telecommunications [standard] 1327
 
 @item MPTA
 Multi Protocol Transport Architecture (IBM, SNA)
@@ -1213,10 +1303,10 @@ MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"
 Macintosh Programmers Workshop (Apple)
 
 @item MPX
-MultiProgramming eXecutive (IBM, OS, IBM 1800)
+MultiProgramming eXecutive (OS)
 
 @item MPX
-MultiProgramming eXecutive (OS)
+MultiProgramming eXecutive (IBM, OS, IBM 1800)
 
 @item MQI
 Message Queueing Interface (IBM)
@@ -1257,6 +1347,9 @@ Multi-Rate Circuit Switching
 @item MRH
 Memory Repeater Hub (Intel)
 
+@item MRIB
+Multicast RPF Routing Information Base (RPF, Multicast, PIM, MSDP)
+
 @item MRJ
 Macintosh / MacOS Runtime for Java (Java, Apple)
 
@@ -1266,6 +1359,9 @@ Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"
 @item MRM
 Multi Resolution Meshes (Intel, 3D)
 
+@item MRML
+Multimedia Retrieval Markup Language (Multimedia, Internet, XML)
+
 @item MRNET
 Minnesota Regional NETwork (network, USA)
 
@@ -1276,7 +1372,10 @@ Mandatory Router Option [flag] (CATNIP)
 Multicommand Required Operational Capability
 
 @item MROM
-??? Read Only Memory (ROM)
+Macrocode Mask Read Only Memory (ROM)
+
+@item MROM
+Mask Read Only Memory (ROM)
 
 @item MRP
 Material / Manufacturing Resource Planning
@@ -1320,6 +1419,9 @@ Mobile Station (GSM, mobile-systems)
 @item MSA
 Management Service Architecture
 
+@item MSA
+MultiSource Assignment
+
 @item MSAP
 Management Service Access Point (OSI, OSI/RM, SAP)
 
@@ -1327,7 +1429,7 @@ Management Service Access Point (OSI, OSI/RM, SAP)
 Mini Slotted Alternating Priorities (MAC)
 
 @item MSB
-Most Significant Bit
+Most Significant Bit (BIT)
 
 @item MSC
 MicroSoft C
@@ -1357,7 +1459,7 @@ Most Significant Digit
 MicroSoft Data Engine (MS, DB)
 
 @item MSDE
-Microsoft SQL Server Desktop Engine (MS, SQL)
+Microsoft SQL server Desktop Engine / Environment (MS, SQL)
 
 @item MSDL
 MicroSoft Download Library (MS)
@@ -1374,9 +1476,18 @@ MicroSoft Developer Network (MS)
 @item MSDOS
 MicroSoft Disk Operating System (MS, OS, PC)
 
+@item MSDP
+Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618)
+
+@item MSE
+Mean Squared Error
+
 @item MSE
 MicroSoft Exchange server (MS)
 
+@item MSE
+Multimedia Software Engineering (Multimedia)
+
 @item MSEN
 Media Status Event Notification
 
@@ -1512,11 +1623,14 @@ Moluccas Time [+0830] (TZ)
 @item MTA
 Mail Transport Agent (SMTP)
 
+@item MTA
+Main Table Area (CD-MRW)
+
 @item MTA
 Message Transfer Agent (MTS, OSI, X.400)
 
 @item MTBF
-Mean Time Between Failure
+Mean Time Between Failure (HDD, ...)
 
 @item MTBRP
 Mean-Time-Between-Parts-Replacement
@@ -1566,6 +1680,9 @@ Magnetic Tape Operating System (OS, Datapoint)
 @item MTP
 Message Transfer Part (ISDN, GSM, mobile-systems)
 
+@item MTR
+Mining Table Repository (OP, Oracle, DB)
+
 @item MTRR
 Memory Type Range Register (CPU, Pentium Pro, IC)
 
@@ -1615,7 +1732,7 @@ Multi-User Chat Kingdom (MUD)
 Multi-User Dungeon (MUD)
 
 @item MUGD
-MUMPS User Group Deutschland (MUMPS, user group), "MUG-D"
+MUMPS User Group Deutschland (MUMPS, user group, Org), "MUG-D"
 
 @item MUI
 Management User Interface (OMF, UI)
@@ -1653,11 +1770,14 @@ Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MP
 @item MUT
 Master Upper Tester (ISO 9646-3, TTCN)
 
+@item MUTIOI
+???, "MuTIOI"
+
 @item MUTOS
 MultiUser-/multitasking Operating System (GDR, OS)
 
 @item MUEW
-eW MonopolUebertragungsWeg, "MueW"
+eW MonopolUEbertragungsWeg, "MueW"
 
 @item MUX
 MUltipleXer
@@ -1707,6 +1827,9 @@ Multiple Virtual Storage/eXtended Architecture, "MVS/XA"
 @item MVT
 Multiprogramming with a Variable number of Tasks (IBM, OS/MVT, OS)
 
+@item MWCM
+Molecular Wire Crossbar Memory (RAM, IC, HP)
+
 @item MWS
 Management WorkStation
 
