@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c Copyright (C) 1993/2003 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -10,11 +10,20 @@
 
 @table @asis
 @item RA
-Registration Authority (PKI, ITU)
+Real Address (Power4, IBM, CPU)
+
+@item RA
+Registration Authority (PKI, ITU, cryptography)
 
 @item RA
 Remote Access (BBS)
 
+@item RAC
+Random Access Channel (HiperLAN/2)
+
+@item RAC
+Real Application Cluster (Oracle)
+
 @item RACE
 Research and technology development in Advanced Communications technologies in Europe (Europe, predecessor, CORDIS)
 
@@ -37,7 +46,7 @@ Rapid Application Development [toolkit] (Delphi, Borland)
 Research And Development [data communications] (manufacturer)
 
 @item RADIUS
-Remote Authentication Dial-In User Service (RFC 2138)
+Remote Authentication Dial-In User Service (RFC 2865)
 
 @item RADSL
 Rate Adaptive Digital Subscriber Line (ADSL)
@@ -111,6 +120,9 @@ Reliable Asynchronous Transfer Protocol (RFC 916)
 @item RATS
 Radio-Amateur Telecommunications Society (org., USA)
 
+@item RATS
+Rough Auditing Tool for Security (WWW, CGI, PERL, PHP,...)
+
 @item RAVE
 Relational Advanced Visual Environment
 
@@ -153,8 +165,11 @@ Return Code (REXX, ...)
 @item RC
 Routing Control
 
-@item RC24
-Ron's Code 2/4 (cryptography), "RC2/4"
+@item RC2
+Rivest Cipher / Ron's Code 2 (cryptography)
+
+@item RC4
+Rivest Cipher / Ron's Code 4 (cryptography)
 
 @item RC5
 Rivest Cipher 5 (RFC 2040, cryptography)
@@ -261,9 +276,15 @@ Random Digital Dial
 @item RDD
 Replaceable Database Driver (Clipper, CA-VO, DB)
 
+@item RDDL
+Resource Directory Description Language (XHTML, XML)
+
 @item RDE
 Received Data Enable
 
+@item RDE
+Ruby Development Environment (Ruby, IDE)
+
 @item RDES
 Remote Data Entry System
 
@@ -274,7 +295,7 @@ Rate Decrease Factor
 Record Definition Field
 
 @item RDF
-Resource Description Framework (IBM, Netscape, MS, ..., WWW)
+Resource Description Framework (XML, IBM, Netscape, MS, ..., WWW)
 
 @item RDH
 RSA-DES-Hybridverschluesselung (cryptography, HBCI)
@@ -297,6 +318,9 @@ Relational Data Modeler
 @item RDM
 Reliably Delivered Message
 
+@item RDMA
+Remote Direct Memory Access (VI)
+
 @item RDN
 Relative Distinguished Name (X.500)
 
@@ -307,10 +331,10 @@ Research Data Network Cooperative Research Centre (org., Australia)
 ??? (CICS, IBM)
 
 @item RDO
-??? (CICS, IBM)
+Remote Data Objects (DB)
 
 @item RDO
-Remote Data Objects (DB)
+Resouce Definition Online (CICS, IBM)
 
 @item RDP
 Reliable Datagram Protocol
@@ -348,6 +372,9 @@ Radio Digital Terminal
 @item RDT
 Restricted Data Transmissions
 
+@item RE
+Recommendation Engine (OP, Oracle, DB)
+
 @item RE
 Research and Engineering, "R&E"
 
@@ -408,6 +435,9 @@ Remote FrameBuffer [protocol]
 @item RFC
 Remote Function Call (SAP, CPIC)
 
+@item RFC
+Request For Change (PERL)
+
 @item RFC
 Request For Comments (Internet, RFC)
 
@@ -415,7 +445,7 @@ Request For Comments (Internet, RFC)
 Ready-For-Data
 
 @item RFD
-Report Fragmentation Done [bit] (CATNIP)
+Report Fragmentation Done [bit] (CATNIP, BIT)
 
 @item RFD
 Request For Discussion (Internet, Usenet), "RfD"
@@ -471,6 +501,12 @@ Remote File Transfer System (DDVS)
 @item RGB
 Rot Gruen Blau / Red Green Blue (color system, DTP)
 
+@item RGBA
+Red Green Blue Alpha-[byte] (color system, RGB)
+
+@item RGBE
+Red Green Blue Emerald (color system, photo, Sony)
+
 @item RGP
 Raster Graphics Processor
 
@@ -480,12 +516,21 @@ Remote Graphics Processor
 @item RH
 Request Header
 
+@item RHS
+Right Hand Side (NGSCB, MS, Palladium)
+
+@item RI
+Reference Implementation (JCP)
+
 @item RI
 Ring Indicator (RS-232, MODEM)
 
 @item RI
 Routing Information
 
+@item RIA
+Rich Internet Application (WWW, Macromedia)
+
 @item RIACS
 Research Institute for Advanced Computer Science (org.)
 
@@ -513,6 +558,9 @@ Rochester Intelligent Gateway (OS)
 @item RII
 Routing Information Indicator
 
+@item RIM
+Registry Information Model (ebXML)
+
 @item RIM
 Remote Installation and Maintenance
 
@@ -525,6 +573,9 @@ Rambus Inline Memory Module (Rambus, IC)
 @item RIO
 Redistributed Internet Objects (S3, VRML, Internet)
 
+@item RIO
+Remote Input/Output (Power4, IBM)
+
 @item RIOCP
 ??? (OS), "RIO/CP "
 
@@ -549,6 +600,9 @@ Routing Information Protocol Next Generation (RIP, IPV6, RFC 2080), "RIPng"
 @item RIPS
 Raster Image Processing Systems corporation (manufacturer)
 
+@item RIR
+Regional Internet Registry (Internet)
+
 @item RIS
 Remote Installation Service
 
@@ -586,7 +640,7 @@ Remote Job Processing
 ROM Kernel Reference Manual (Amiga, Commodore)
 
 @item RL
-Real Life (DFUe, Usenet, IRC)
+Real Life (telecommunication, Usenet, IRC)
 
 @item RL
 Reconfigurable Logic (RL)
@@ -612,6 +666,9 @@ Radio Link Protocol (GSM, mobile-systems)
 @item RLP
 Resource Location Protocol (Internet, RFC 887)
 
+@item RLS
+Read Link error Status (FCP)
+
 @item RLS
 Received Line Signal
 
@@ -630,12 +687,18 @@ RingLeitungsVerteiler
 @item RM
 Resource Management
 
+@item RM
+Retention Module
+
 @item RMAS
 Remote Memory Administration System
 
 @item RMATS
 Remote Maintenance Administration and Traffic
 
+@item RMC
+Rambus Memory Controller (Rambus)
+
 @item RMCOS
 Ryan-McFarland COBOL (????) Operating System (OS, COBOL), "RM/COS"
 
@@ -654,15 +717,18 @@ Remote MONitoring
 @item RMOS
 Realtime Multitasking Operating System (SNI, OS)
 
-@item RMS
-??? [bus]
-
 @item RMS
 Reason Maintenance System (AI)
 
+@item RMS
+Remote Monitoring System [bus]
+
 @item RMS
 Richard Matthew Stallman (FSF, EMACS)
 
+@item RMS
+Rights Management Services (MS, Windows, NGSCB)
+
 @item RMT
 Raw Magnetic Tape (Unix)
 
@@ -675,15 +741,24 @@ REXXware Migration Tool (Simware, REXX)
 @item RMT
 Ring ManagemenT (FDDI, SMT)
 
+@item RMX
+Reverse Mail eXchange (DNS)
+
 @item RNA
 Remote Network Access
 
+@item RNC
+Radio Network Controller (mobile-systems, UMTS)
+
 @item RND
 RAD Network Devices (RAD, manufacturer)
 
 @item RNI
 Raw Native Interface (MS, Java)
 
+@item RNID
+Request Node IDentification (FCP, SNIA, HBA, API)
+
 @item RNOC
 Regional Network Operations Center
 
@@ -711,6 +786,9 @@ Reusable Object Access and Management System
 @item ROC
 RAID On a Chip (RAID)
 
+@item ROC
+Reconstruction Of Color (ICE, Scanner)
+
 @item ROCF
 Remote Object Class Factory
 
@@ -720,6 +798,9 @@ Rewritable Optical Disk (OD)
 @item ROFL
 Roar Out From Laughing (slang, Usenet, IRC)
 
+@item ROHC
+RObust Header Compression (RFC 3095, RTP, UDP, ESP)
+
 @item ROLAP
 Relational OnLine Analytical Processing (OLAP, DB)
 
@@ -765,6 +846,9 @@ Rendezvous Point (PIM, Multicast)
 @item RPA
 Remote Phrase Authentication
 
+@item RPC
+Region Playback Control (DVD)
+
 @item RPC
 Remote Procedure Call (Sun, Xerox, OSF, ECMA, RFC 1831)
 
@@ -780,6 +864,9 @@ Remote Peripheral Equipment
 @item RPELTP
 Regular Pulse Excitation with Long-Term Prediction [loop] (LPC), "RPE-LTP"
 
+@item RPF
+Rendezvous Point Forwarding (PIM, MSDP, Multicast, RP)
+
 @item RPF
 RePeat active File (IBM, VM/ESA, CP)
 
@@ -813,6 +900,9 @@ Reverse Polish Notation
 @item RPP
 Relative Processor Performance (CPU, Cray)
 
+@item RPS
+Read Port Status (FCP)
+
 @item RPS
 Realtime Programming System (OS, IBM)
 
@@ -834,6 +924,9 @@ Relative Record Data Set (VSAM)
 @item RRIP
 Rock Ridge Interchange Protocol (CD, Unix)
 
+@item RRO
+Radial Run Out (DVD)
+
 @item RRZE
 Regionales RechenZentrum Erlangen (org.)
 
@@ -844,7 +937,10 @@ Regionales RechenZentrum fuer Niedersachsen (org.)
 Recommended Standard
 
 @item RS
-Registry Service (DCE)
+Reconciliation Sublayer (10GE, OSI)
+
+@item RS
+Registry Service (DCE, ebXML, ...)
 
 @item RSA
 Random Scheduling Algorithm [protocol]
@@ -867,6 +963,12 @@ Remote Service Access Point (SAP)
 @item RSAT
 Reliability and System Architecture Testing
 
+@item RSBAC
+Rule Set Base Access Control (Linux)
+
+@item RSCN
+Registered State Change Notification (FCP)
+
 @item RSCS
 Remote Source Control System
 
@@ -897,6 +999,9 @@ Retrieve Subsequent File Descriptor (IBM, VM/ESA, CP)
 @item RSFDNPR
 Retrieve Subsequent File Descriptor Not Previously Retrieved (IBM, VM/ESA, CP)
 
+@item RSFQ
+Rapid Single Flux Quantum [logic]
+
 @item RSH
 Remote SHell (Unix, BSD, Shell)
 
@@ -922,7 +1027,10 @@ Real Soon Now (slang)
 Reality Signal Processor (Nintendo)
 
 @item RSPC
-Reed Solomon Product Code (SDD), "RS-PC"
+Reed Solomon Product Code (SDD, CD), "RS-PC"
+
+@item RSS
+Rich Site Summary (XML)
 
 @item RSSCP
 Remote System Services Control Point (SSCP)
@@ -976,7 +1084,7 @@ Remote Teleprocessing Access Method
 Read Tape Binary
 
 @item RTBM
-Real Time Bit Mapping
+Real Time Bit Mapping (BIT)
 
 @item RTC
 Real Time Clock
@@ -1041,6 +1149,9 @@ Routing Table Generator
 @item RTI
 ReTurn from Interrupt
 
+@item RTIN
+Request Topology INformation (FCP, SNIA, HBA, API)
+
 @item RTL
 Real Time Language
 
@@ -1053,7 +1164,8 @@ Resistor-Transistor Logic
 @item RTL
 RunTime Library
 
-RTLinux      Real-Time Linux (Linux)
+@item RTLINUX
+Real-Time Linux (Linux)
 
 @item RTM
 Registered Transfer Module
@@ -1109,6 +1221,9 @@ RealTime System Manager
 @item RTSP
 Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast)
 
+@item RTT
+Resonant Tunneling Transistor
+
 @item RTT
 Round-Trip Time
 
@@ -1134,7 +1249,7 @@ Real Time UniX (OS, Emerge Systems)
 Real Time Video
 
 @item RTVBR
-RealTime Variable Bit Rate (VBR, ATM), "rt-VBR"
+RealTime Variable Bit Rate (VBR, ATM, BIT), "rt-VBR"
 
 @item RTX
 Real Time eXecutive (OS)
@@ -1160,12 +1275,18 @@ Rechenzentrum der Universitaet Stuttgart (org., Uni Stuttgart, Germany)
 @item RVD
 Remote Virtual Disk
 
+@item RVPPIP
+Rendez-Vous Protocol / Presence Information Protocol (IM), "RVP/PIP"
+
 @item RW
 Read/Write (I/O), "R/W"
 
 @item RWCP
 Real World Computing Partnership (org., Japan)
 
+@item RWPPI
+ReWritable Product Promotion Initiative (org., DVD-R, DVD-RW, DVD)
+
 @item RWS
 Remote WinSock (Windows, TCP/IP)
 
